@@ -145,7 +145,7 @@ def extract_zip(data: BytesIO, path: Path) -> None:
         if chromium_executable().exists() and zip_path.exists():
             zip_path.unlink()
     else:
-        with ZipFile(data) as zf:
+        with ZipFile(data, 'wb') as zf:
             zf.extractall(str(path))
     exec_path = chromium_executable()
     if not exec_path.exists():
